@@ -467,8 +467,7 @@ const Application = new Lang.Class({
             { name: 'gear-menu',
               callback: this._onActionToggle,
               state: GLib.Variant.new('b', false),
-              accel: 'F10',
-              window_mode: WindowMode.WindowMode.PREVIEW },
+              accel: 'F10' },
             { name: 'view-as',
               callback: this._onActionViewAs,
               create_hook: this._viewAsCreateHook,
@@ -591,7 +590,6 @@ const Application = new Lang.Class({
         // clean up signals
         changeMonitor.disconnectAll();
         documentManager.disconnectAll();
-        offsetController.disconnectAll();
         trackerController.disconnectAll();
         selectionController.disconnectAll();
         modeController.disconnectAll();
