@@ -729,18 +729,19 @@ const LocalDocument = new Lang.Class({
             return;
 
         let file = Gio.file_new_for_uri(this.uri);
-        file.trash_async(GLib.PRIORITY_DEFAULT, null, Lang.bind(this,
+        file.delete_async(GLib.PRIORITY_DEFAULT, null, Lang.bind(this,
             function(source, res) {
                 try {
-                    file.trash_finish(res);
+                    file.delete_finish(res);
                 } catch(e) {
-                    log('Unable to trash ' + this.uri + ': ' + e.message);
+                    log('Unable to delete ' + this.uri + ': ' + e.message);
                 }
             }));
     }
 });
 
-const GOOGLE_PREFIX = 'google:drive:';
+const _GOOGLE_DOCS_SCHEME_LABELS = "http://schemas.google.com/g/2005/labels";
+const _GOOGLE_DOCS_TERM_STARRED = "http://schemas.google.com/g/2005/labels#starred";
 
 const GoogleDocument = new Lang.Class({
     Name: 'GoogleDocument',
@@ -761,11 +762,10 @@ const GoogleDocument = new Lang.Class({
 
         let authorizer = new GData.GoaAuthorizer({ goa_object: source.object });
         let service = new GData.DocumentsService({ authorizer: authorizer });
-        let gdata_id = this.identifier.substring(GOOGLE_PREFIX.length);
 
         service.query_single_entry_async
             (GData.DocumentsService.get_primary_authorization_domain(),
-             gdata_id, null,
+             this.identifier, null,
              GData.DocumentsText,
              cancellable, Lang.bind(this,
                  function(object, res) {
@@ -1125,7 +1125,7 @@ const DocumentManager = new Lang.Class({
 
     _identifierIsGoogle: function(identifier) {
         return (identifier &&
-                (identifier.indexOf(GOOGLE_PREFIX) != -1));
+                (identifier.indexOf('https://docs.google.com') != -1));
     },
 
     _identifierIsOwncloud: function(identifier) {
