@@ -204,6 +204,7 @@ const Embed = new Lang.Class({
     Name: 'Embed',
 
     _init: function() {
+        this._queryErrorId = 0;
         this._noResultsChangeId = 0;
         this._loadShowId = 0;
 
@@ -384,6 +385,8 @@ const Embed = new Lang.Class({
     },
 
     _onLoadStarted: function() {
+        Application.modeController.setWindowMode(WindowMode.WindowMode.PREVIEW);
+
         this._clearLoadTimer();
         this._loadShowId = Mainloop.timeout_add(_PDF_LOADER_TIMEOUT, Lang.bind(this,
             function() {
@@ -396,8 +399,6 @@ const Embed = new Lang.Class({
     },
 
     _onLoadFinished: function(manager, doc, docModel) {
-        Application.modeController.setWindowMode(WindowMode.WindowMode.PREVIEW);
-
         docModel.set_sizing_mode(EvView.SizingMode.AUTOMATIC);
         docModel.set_page_layout(EvView.PageLayout.AUTOMATIC);
         this._toolbar.setModel(docModel);
@@ -410,8 +411,6 @@ const Embed = new Lang.Class({
     },
 
     _onLoadError: function(manager, doc, message, exception) {
-        Application.modeController.setWindowMode(WindowMode.WindowMode.PREVIEW);
-
         this._clearLoadTimer();
         this._spinnerBox.stop();
         this._setError(message, exception.message);
@@ -432,7 +431,7 @@ const Embed = new Lang.Class({
 
     _prepareForOverview: function() {
         if (this._preview)
-            this._preview.setModel(null);
+            this._preview.reset();
         if (this._edit)
             this._edit.setUri(null);
         if (this._toolbar)
@@ -455,6 +454,8 @@ const Embed = new Lang.Class({
         // pack the toolbar
         this._toolbar = new Preview.PreviewToolbar(this._preview);
         this._titlebar.add(this._toolbar.widget);
+
+        this._stack.set_visible_child_name('preview');
     },
 
     _prepareForEdit: function() {
